/* ========================================
 *
 * Copyright VIOR, 2014
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF VIOR.
 *
 * ========================================
*/

/* [] END OF FILE */

#include <device.h>

#define MSMode_Init 0 
#define MSMode_RXTXMask 0x80
#define MSMode_RX 0x00 
#define MSMode_TX 0x80 

#define MSMode_StateMask 0x3F
#define MSMode_StateReset 0x00
#define MSMode_StateSetSampleRate0Cmd 0x01
#define MSMode_StateSetSampleRate0Val 0x02
#define MSMode_StateSetSampleRate1Cmd 0x03
#define MSMode_StateSetSampleRate1Val 0x04
#define MSMode_StateSetSampleRate2Cmd 0x05
#define MSMode_StateSetSampleRate2Val 0x06
#define MSMode_StateGetdeviceID 			0x07
#define MSMode_SetRemoteMode          0x08
#define MSMode_ReadData            		0x09
#define MSMode_StateSetSampleRate3Cmd 0x0A
#define MSMode_StateSetSampleRate3Val 0x0B
//#define MSMode_EnableDataReporting		0x09
//#define MSMode_StateSetSampleRate3Cmd 0x0A
//#define MSMode_StateSetSampleRate3Val 0x0B


#define MSFrame_DelayMs 20 

uint8 MouseMode = MSMode_Init;
uint8 MouseDataReg = 0;
uint8 MouseBitNum = 0;
uint8 MouseData[8];
uint8 MouseByteNum = 0;
TSysClk MouseLastAct = 0;
uint8 MouseMidBtn = 0;


void MouseData_WriteRee(uint8 value) reentrant {
  uint8 staticBits = (MouseData_DR & (uint8)(~MouseData_MASK));
  MouseData_DR = staticBits | ((uint8)(value << MouseData_SHIFT) & MouseData_MASK);
}

uint8 MouseData_ReadRee(void) reentrant {
    return (MouseData_PS & MouseData_MASK);
}

uint8 MouseClk_ReadRee(void) reentrant {
    return (MouseClk_PS & MouseClk_MASK);
}

bool ParityCheckOdd(bool AParityBit) {
uint8 Data = MouseDataReg;	
uint8 BitCnt = AParityBit;	
  if (AParityBit) BitCnt = 1;
	else BitCnt = 0;
	while (Data != 0) {
  	Data &= (Data - 1);
		BitCnt++;
	}
  return (BitCnt % 2);
}

void MSCommReset (void) {
	MouseBitNum = 0; 
	MouseByteNum = 0;
}

CY_ISR(MouseIrqHandler) {	
	if (MouseClk_ReadRee() == 0) {
	  if (((MouseMode & MSMode_RXTXMask) == MSMode_RX) /*&& (MouseClk_Read() == 0)*/) {//from the device to the host is read on the falling edge
			if (MouseBitNum != 0) {  //если не старт бит, то проверить последнюю активность сигнала на CLK, и если дольше MSFrame_DelayMs, то сбросить					
				if (SysClk_GetPeriod(MouseLastAct) > MSFrame_DelayMs) {
					MSCommReset();
				}
			} 		
		  if (MouseBitNum == 0) {  //1 start bit.  This is always 0.
				if (MouseData_ReadRee() == 0) {
					MouseBitNum++; 
					MouseDataReg = 0;
				}
			} else if ((MouseBitNum >= 1) && (MouseBitNum <= 8)) { //8 data bits, least significant bit first.
				MouseBitNum++;
				MouseDataReg >>= 1;
				if (MouseData_ReadRee()) MouseDataReg |= 0x80;
			} else if (MouseBitNum == 9) { //1 parity bit (odd parity).
				MouseBitNum++;
				if (!ParityCheckOdd(MouseData_ReadRee())) {
					MSCommReset();
				}
			} else if (MouseBitNum == 10) { //1 stop bit.  This is always 1.
				if (MouseData_ReadRee() != 0) { //данные получены
					if (MouseByteNum < sizeof(MouseData)) {
						MouseData[MouseByteNum] = MouseDataReg;
						MouseByteNum++;
					}				
				}
				MouseBitNum = 0; 		
			}
		} else  /*if (MouseMode == MSMode_Transmit)*/ {		
			if (MouseBitNum < 9) {  				//8 data bits, least significant bit first.
				MouseData_WriteRee(MouseDataReg & 0x01);
				MouseDataReg >>= 1;
			} else if (MouseBitNum == 9) {  //1 parity bit (odd parity).
				MouseDataReg = MouseData[0];
				if (ParityCheckOdd(TRUE)) MouseData_WriteRee(0x01);
				else MouseData_WriteRee(0x00);
			} else  if (MouseBitNum == 10) {  //1 stop bit.  This is always 1.			
				MouseData_WriteRee(0x01);
			} else {			//check ACK
				if (MouseData_ReadRee() == 1) { //нет ACK от устройства
					GlobalError_SET(ERR_Mouse_NoDevice);
				}
				MouseBitNum = 0xFF;
				MouseMode &= ~MSMode_RXTXMask;			
			}
			MouseBitNum++;
	  }
		MouseLastAct = SysClkCounter_ReadCounter();
	}
	MouseClk_ClearInterrupt();
}


void MouseModeToRecieve (void) {
	MouseMode &= ~MSMode_RXTXMask;
}

void MouseTransmit (uint8 Data) {
//	if ((MouseBitNum != 0) && (SysClk_GetPeriod(MouseLastAct) < MSFrame_DelayMs)) return;
	MouseISR_Disable();
	MouseData[0] = Data;
	MouseDataReg = Data;
	MouseByteNum = 0x00;
	MouseBitNum = 0x01; 
	MouseMode |= MSMode_TX;
	MouseClk_Write(0);  //1)   Bring the Clock line low for at least 100 microseconds.
	CyDelayUs(100);
	MouseData_WriteRee(0); //2)   Bring the Data line low.
	MouseClk_Write(1);  //3)   Release the Clock line.		
	MouseISR_Enable();  //4)   Wait for the device to bring the Clock line low.
//	MouseClk_ClearInterrupt();
}

#define MSMode_StateSET(STATE) {MouseMode = (MouseMode & ~MSMode_StateMask) | STATE;}
#define MSMode_StateGET (MouseMode & MSMode_StateMask)
#define MSMode_RXByteReady(MinCount) ((MouseByteNum >= MinCount) && (SysClk_GetPeriod(MouseLastAct) > MSFrame_DelayMs))

void InitMouse (void) {
	MSMode_StateSET(MSMode_StateReset);
//	MouseMode = (MouseMode & ~MSMode_StateMask) | MSMode_StateReset;
	MouseMode |= MSMode_TX;
	MouseBitNum = 0x00;
	MouseISR_StartEx(MouseIrqHandler);
	//MouseMode = MSMode_Recieve;
//	MouseTransmit(0xFF);
}

bool MouseStateMachine (uint8 TXData, uint8 ExpectRXAnswer_0, uint8 ExpectRXMinCount, uint8 NextState, TSysClk ATimeOut) {
TSysClk ActPeriod = SysClk_GetPeriod(MouseLastAct);
	if ((MouseMode & MSMode_RXTXMask) == MSMode_TX) {
		if ((MouseBitNum == 0) /*|| (ActPeriod > 100)*/) {
			MouseTransmit(TXData);
		} else if (ActPeriod > 1000) {
			MSMode_StateSET(MSMode_StateReset);
			MouseMode |= MSMode_TX;
			MouseBitNum = 0x00;		
			MouseLastAct = SysClkCounter_ReadCounter();
		}
	} else {		
		if ((MouseByteNum >= ExpectRXMinCount) && (ActPeriod >= MSFrame_DelayMs)) {
			if (MouseData[0] == ExpectRXAnswer_0) {
				MSMode_StateSET(NextState);
				MouseMode |= MSMode_TX;
				return (TRUE);
			}	else {
				MSMode_StateSET(MSMode_StateReset);
				MouseMode |= MSMode_TX;
				MouseBitNum = 0x00;
			}
		} else if (ActPeriod > ATimeOut) {
			MSMode_StateSET(MSMode_StateReset);
			MouseMode |= MSMode_TX;
			MouseBitNum = 0x00;		
		}
	}
	return (FALSE);
}

void MouseHandler (void) {
static TSysClk MouseClkCounter = 0xFFFF;	 
	
	if (MSMode_StateGET == MSMode_StateReset) {
//		LED_MouseIsLost();
		if (MouseStateMachine(0xFF, 0xFA, 3, MSMode_StateSetSampleRate0Cmd, 800)) {		  
			GlobalError_CLEAR(ERR_Mouse_NoDevice);	
		} else GlobalError_SET(ERR_Mouse_NoDevice);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate0Cmd) {  //Intellimouse Установить частоту дискретизации =200
		MouseStateMachine(0xF3, 0xFA, 1, MSMode_StateSetSampleRate0Val, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate0Val) {
		MouseStateMachine(200, 0xFA, 1, MSMode_StateSetSampleRate1Cmd, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate1Cmd) {  //Установить частоту дискретизации =100
		MouseStateMachine(0xF3, 0xFA, 1, MSMode_StateSetSampleRate1Val, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate1Val) {
		MouseStateMachine(100, 0xFA, 1, MSMode_StateSetSampleRate2Cmd, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate2Cmd) {  //Установить частоту дискретизации =80
		MouseStateMachine(0xF3, 0xFA, 1, MSMode_StateSetSampleRate2Val, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate2Val) {
		MouseStateMachine(80, 0xFA, 1, MSMode_StateGetdeviceID, 100);
	} else if (MSMode_StateGET == MSMode_StateGetdeviceID) {
		if (MouseStateMachine(0xF2, 0xFA, 2, MSMode_SetRemoteMode, 100)) {
			if (MouseData[1] != 0x03) {  //если будет подключена Microsoft Intellimouse, то она ответит ID =0×03.
				MSMode_StateSET(MSMode_StateReset);
				MouseMode |= MSMode_TX;
				MouseBitNum = 0x00;
				GlobalError_SET(ERR_Mouse_NoWheel);
			} else {
				GlobalError_CLEAR(ERR_Mouse_NoWheel);
			}
		} else GlobalError_SET(ERR_Mouse_NoWheel);
	} else if (MSMode_StateGET == MSMode_SetRemoteMode) {
		MouseStateMachine(0xF0, 0xFA, 1, MSMode_StateSetSampleRate3Cmd, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate3Cmd) {  //Установить частоту дискретизации =100
		MouseStateMachine(0xF3, 0xFA, 1, MSMode_StateSetSampleRate3Val, 100);
	} else if (MSMode_StateGET == MSMode_StateSetSampleRate3Val) {
		/*if (*/MouseStateMachine(100, 0xFA, 1, MSMode_ReadData, 100);//) LED_MouseIsFound();
	}	else if (MSMode_StateGET == MSMode_ReadData) {
		if (!SysClk_CheckPeriod(&MouseClkCounter, 50)) return; //период опроса мыши 100мс 
		if (MouseStateMachine(0xEB, 0xFA, 5, MSMode_ReadData, 100)) {			
			uint8 msDt = MouseData[1];			
			int8 i8 = MouseData[4];
			float mult;
			

		//	else if (msDt & 0x04) PowerUnit.MouseStatus |= MSS_MSBtnMid;
			
			if (WorkMode_ModeGET != WM_PowerOFF) {
				if (WorkMode_ModeGET == WM_VoltStab) {
					if (LCDMenu_ModeGET == LM_CurrentChng) {					
						if (i8 > 0) {
							if (msDt & 0x01) mult = 1; //BtnLeft;
							else if (msDt & 0x02) mult = 0.25; //MSS_MSBtnRight;
							else mult = 0.01;						
							CurrentSP_Inc(mult * i8);
							LCDMenuBackToMainMenuReset();
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -1; //BtnLeft;
							else if (msDt & 0x02) mult = -0.25; //MSS_MSBtnRight;
							else mult = -0.01;	
							CurrentSP_Dec(mult * i8); 
							LCDMenuBackToMainMenuReset();
						}
					} else {
						if (i8 > 0) {
							if (msDt & 0x01) mult = 2.0; //BtnLeft;
							else if (msDt & 0x02) mult = 1.0; //MSS_MSBtnRight;
							else mult = 0.1;	
							VoltageSP_Inc(mult * i8);
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -2.0; //BtnLeft;
							else if (msDt & 0x02) mult = -1.0; //MSS_MSBtnRight;
							else mult = -0.1;
							VoltageSP_Dec(mult * i8); 
						}				
					}
				} else if (WorkMode_ModeGET == WM_CurrStab) {
					if (LCDMenu_ModeGET == LM_VoltageChng) {					
						if (i8 > 0) {
							if (msDt & 0x01) mult = 2.0; //BtnLeft;
							else if (msDt & 0x02) mult = 1.0; //MSS_MSBtnRight;
							else mult = 0.1;	
							VoltageSP_Inc(mult * i8);
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -2.0; //BtnLeft;
							else if (msDt & 0x02) mult = -1.0; //MSS_MSBtnRight;
							else mult = -0.1;
							VoltageSP_Dec(mult * i8); 
						}	
					} else {
						if (i8 > 0) {
							if (msDt & 0x01) mult = 1; //BtnLeft;
							else if (msDt & 0x02) mult = 0.25; //MSS_MSBtnRight;
							else mult = 0.01;						
							CurrentSP_Inc(mult * i8);
							LCDMenuBackToMainMenuReset();
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -1; //BtnLeft;
							else if (msDt & 0x02) mult = -0.25; //MSS_MSBtnRight;
							else mult = -0.01;	
							CurrentSP_Dec(mult * i8); 
							LCDMenuBackToMainMenuReset();
						}			
					}
				} else if (WorkMode_ModeGET == WM_BatteryChrg) {
					if (LCDMenu_ModeGET == LM_VoltageChng) {					
						if (i8 > 0) {
							if (msDt & 0x01) mult = 2.0; //BtnLeft;
							else if (msDt & 0x02) mult = 1.0; //MSS_MSBtnRight;
							else mult = 0.1;	
							VoltageSP_Inc(mult * i8);
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -2.0; //BtnLeft;
							else if (msDt & 0x02) mult = -1.0; //MSS_MSBtnRight;
							else mult = -0.1;
							VoltageSP_Dec(mult * i8); 
						}	
					} else {
						if (i8 > 0) {
							if (msDt & 0x01) mult = 1; //BtnLeft;
							else if (msDt & 0x02) mult = 0.25; //MSS_MSBtnRight;
							else mult = 0.01;						
							CurrentSP_Inc(mult * i8);
							LCDMenuBackToMainMenuReset();
						} else if (i8 < 0) {
							if (msDt & 0x01) mult = -1; //BtnLeft;
							else if (msDt & 0x02) mult = -0.25; //MSS_MSBtnRight;
							else mult = -0.01;	
							CurrentSP_Dec(mult * i8); 
							LCDMenuBackToMainMenuReset();
						}			
					}
				}
				
				if ((msDt & 0x04) != MouseMidBtn) {
					MouseMidBtn = (msDt & 0x04);
					if (MouseMidBtn) {
						if (PowerUnit.Error & ERR_NewError) {
							ResetError();
						} else {							
							if ((OUT_ON_R_Read() == 0) && (msDt & 0x02)) { //MSS_MSBtnRight; при включении выхода, правой кнопкой блокировать защиту	
								HwPrSupress(TRUE);
//								HwPrNoOverCurrent_ON();
//								HwPrNoOverVoltage_ON();	
//								PowerUnit.HwPrSupressed = TRUE;
//								LED_HwPrSupressON();
							} else {
								HwPrSupress(FALSE);
//								PowerUnit.HwPrSupressed = FALSE;
//								LED_HwPrSupressOFF();
							}
							OutputControlChng();		
//							if (MouseRightBtnDsblHwPr && (msDt & 0x02)) {
//								CyDelay (10);
//								HwPrErrorClr();
//							}
						}
					}
				}
				if (PowerUnit.HwPrSupressed && ((msDt & 0x02) == 0) /*&& (OUT_ON_R_Read() != 0)*/) {
					HwPrSupress(FALSE);
//					HwPrErrorClr();
//					HwPrNoOverCurrent_OFF();
//					HwPrNoOverVoltage_OFF();
//					PowerUnit.HwPrSupressed = FALSE;
//					LED_HwPrSupressOFF();
				}
			}
		}
	}
}