/*******************************************************************************
* File Name: CtrlVolt24.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "CtrlVolt24.h"


/*******************************************************************************
* Function Name: CtrlVolt24_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void CtrlVolt24_Write(uint8 value) 
{
    uint8 staticBits = (CtrlVolt24_DR & (uint8)(~CtrlVolt24_MASK));
    CtrlVolt24_DR = staticBits | ((uint8)(value << CtrlVolt24_SHIFT) & CtrlVolt24_MASK);
}


/*******************************************************************************
* Function Name: CtrlVolt24_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  CtrlVolt24_DM_STRONG     Strong Drive 
*  CtrlVolt24_DM_OD_HI      Open Drain, Drives High 
*  CtrlVolt24_DM_OD_LO      Open Drain, Drives Low 
*  CtrlVolt24_DM_RES_UP     Resistive Pull Up 
*  CtrlVolt24_DM_RES_DWN    Resistive Pull Down 
*  CtrlVolt24_DM_RES_UPDWN  Resistive Pull Up/Down 
*  CtrlVolt24_DM_DIG_HIZ    High Impedance Digital 
*  CtrlVolt24_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void CtrlVolt24_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(CtrlVolt24_0, mode);
}


/*******************************************************************************
* Function Name: CtrlVolt24_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CtrlVolt24_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CtrlVolt24_Read(void) 
{
    return (CtrlVolt24_PS & CtrlVolt24_MASK) >> CtrlVolt24_SHIFT;
}


/*******************************************************************************
* Function Name: CtrlVolt24_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CtrlVolt24_ReadDataReg(void) 
{
    return (CtrlVolt24_DR & CtrlVolt24_MASK) >> CtrlVolt24_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CtrlVolt24_INTSTAT) 

    /*******************************************************************************
    * Function Name: CtrlVolt24_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CtrlVolt24_ClearInterrupt(void) 
    {
        return (CtrlVolt24_INTSTAT & CtrlVolt24_MASK) >> CtrlVolt24_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
