/*******************************************************************************
* File Name: CurrCompensAmpl.c  
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "CurrCompensAmpl.h"

#if (!CY_PSOC5A)
    #if (CYDEV_VARIABLE_VDDA == 1u)
        #include "CyScBoostClk.h"
    #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
#endif /* (!CY_PSOC5A) */

#if (CY_PSOC5A)
    static CurrCompensAmpl_BACKUP_STRUCT  CurrCompensAmpl_P5backup;
#endif /* (CY_ PSOC5A) */

uint8 CurrCompensAmpl_initVar = 0u;


/*******************************************************************************   
* Function Name: CurrCompensAmpl_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  CurrCompensAmpl_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CurrCompensAmpl_Init(void) 
{
    /* Set PGA mode */
    CurrCompensAmpl_CR0_REG = CurrCompensAmpl_MODE_PGA;      
    /* Set non-inverting PGA mode and reference mode */
    CurrCompensAmpl_CR1_REG |= CurrCompensAmpl_PGA_NINV;  
    /* Set default gain and ref mode */
    CurrCompensAmpl_CR2_REG = CurrCompensAmpl_VREF_MODE;
    /* Set gain and compensation */
    CurrCompensAmpl_SetGain(CurrCompensAmpl_DEFAULT_GAIN);
    /* Set power */
    CurrCompensAmpl_SetPower(CurrCompensAmpl_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: CurrCompensAmpl_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CurrCompensAmpl_Enable(void) 
{
    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modifications in stop() API */
    #if (CY_PSOC5A)
        if(CurrCompensAmpl_P5backup.enableState == 1u)
        {
            CurrCompensAmpl_CR1_REG = CurrCompensAmpl_P5backup.scCR1Reg;
            CurrCompensAmpl_CR2_REG = CurrCompensAmpl_P5backup.scCR2Reg;
            CurrCompensAmpl_P5backup.enableState = 0u;
        }
    #endif /* CY_PSOC5A */   

    /* Enable power to the Amp in Active mode*/
    CurrCompensAmpl_PM_ACT_CFG_REG |= CurrCompensAmpl_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    CurrCompensAmpl_PM_STBY_CFG_REG |= CurrCompensAmpl_STBY_PWR_EN;
    
    CurrCompensAmpl_PUMP_CR1_REG |= CurrCompensAmpl_PUMP_CR1_SC_CLKSEL;
    
    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            if(CyScPumpEnabled == 1u)
            {
                CurrCompensAmpl_BSTCLK_REG &= (uint8)(~CurrCompensAmpl_BST_CLK_INDEX_MASK);
                CurrCompensAmpl_BSTCLK_REG |= CurrCompensAmpl_BST_CLK_EN | CyScBoostClk__INDEX;
                CurrCompensAmpl_SC_MISC_REG |= CurrCompensAmpl_PUMP_FORCE;
                CyScBoostClk_Start();
            }
            else
            {
                CurrCompensAmpl_BSTCLK_REG &= (uint8)(~CurrCompensAmpl_BST_CLK_EN);
                CurrCompensAmpl_SC_MISC_REG &= (uint8)(~CurrCompensAmpl_PUMP_FORCE);
            }
        #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
    #endif /* (!CY_PSOC5A) */
}


/*******************************************************************************
* Function Name: CurrCompensAmpl_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CurrCompensAmpl_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(CurrCompensAmpl_initVar == 0u)
    {
        CurrCompensAmpl_Init();
        CurrCompensAmpl_initVar = 1u;
    }

    CurrCompensAmpl_Enable();
}


/*******************************************************************************
* Function Name: CurrCompensAmpl_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void CurrCompensAmpl_Stop(void) 
{ 
    /* Disble power to the Amp in Active mode template */
    CurrCompensAmpl_PM_ACT_CFG_REG &= (uint8)(~CurrCompensAmpl_ACT_PWR_EN);

    /* Disble power to the Amp in Alternative Active mode template */
    CurrCompensAmpl_PM_STBY_CFG_REG &= (uint8)(~CurrCompensAmpl_STBY_PWR_EN);

    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            CurrCompensAmpl_BSTCLK_REG &= (uint8)(~CurrCompensAmpl_BST_CLK_EN);
            /* Disable pumps only if there aren't any SC block in use */
            if ((CurrCompensAmpl_PM_ACT_CFG_REG & CurrCompensAmpl_PM_ACT_CFG_MASK) == 0u)
            {
                CurrCompensAmpl_SC_MISC_REG &= (uint8)(~CurrCompensAmpl_PUMP_FORCE);
                CurrCompensAmpl_PUMP_CR1_REG &= (uint8)(~CurrCompensAmpl_PUMP_CR1_SC_CLKSEL);
                CyScBoostClk_Stop();
            }
        #endif /* CYDEV_VARIABLE_VDDA == 1u */
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        CurrCompensAmpl_P5backup.scCR1Reg = CurrCompensAmpl_CR1_REG;
        CurrCompensAmpl_P5backup.scCR2Reg = CurrCompensAmpl_CR2_REG;
        CurrCompensAmpl_CR1_REG = 0x00u;
        CurrCompensAmpl_CR2_REG = 0x00u;
        CurrCompensAmpl_P5backup.enableState = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: CurrCompensAmpl_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void CurrCompensAmpl_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = CurrCompensAmpl_CR1_REG & (uint8)(~CurrCompensAmpl_DRIVE_MASK);
    tmpCR |= (power & CurrCompensAmpl_DRIVE_MASK);
    CurrCompensAmpl_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: CurrCompensAmpl_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void CurrCompensAmpl_SetGain(uint8 gain) 
{
    /* Constant array for gain settings */
    const uint8 CurrCompensAmpl_GainArray[9] = { 
        (CurrCompensAmpl_RVAL_0K   | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=1  */
        (CurrCompensAmpl_RVAL_40K  | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=2  */
        (CurrCompensAmpl_RVAL_120K | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=4  */
        (CurrCompensAmpl_RVAL_280K | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=8  */
        (CurrCompensAmpl_RVAL_600K | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=16 */
        (CurrCompensAmpl_RVAL_460K | CurrCompensAmpl_R20_40B_40K | CurrCompensAmpl_BIAS_LOW), /* G=24, Sets Rin as 20k */
        (CurrCompensAmpl_RVAL_620K | CurrCompensAmpl_R20_40B_20K | CurrCompensAmpl_BIAS_LOW), /* G=32 */
        (CurrCompensAmpl_RVAL_470K | CurrCompensAmpl_R20_40B_20K | CurrCompensAmpl_BIAS_LOW), /* G=48, Sets Rin as 10k */
        (CurrCompensAmpl_RVAL_490K | CurrCompensAmpl_R20_40B_20K | CurrCompensAmpl_BIAS_LOW)  /* G=50, Sets Rin as 10k */
    };
    
    /* Constant array for gain compenstion settings */
    const uint8 CurrCompensAmpl_GainComp[9] = { 
        ( CurrCompensAmpl_COMP_4P35PF  | (uint8)( CurrCompensAmpl_REDC_00 >> 2 )), /* G=1  */
        ( CurrCompensAmpl_COMP_4P35PF  | (uint8)( CurrCompensAmpl_REDC_01 >> 2 )), /* G=2  */
        ( CurrCompensAmpl_COMP_3P0PF   | (uint8)( CurrCompensAmpl_REDC_01 >> 2 )), /* G=4  */
        ( CurrCompensAmpl_COMP_3P0PF   | (uint8)( CurrCompensAmpl_REDC_01 >> 2 )), /* G=8  */
        ( CurrCompensAmpl_COMP_3P6PF   | (uint8)( CurrCompensAmpl_REDC_01 >> 2 )), /* G=16 */
        ( CurrCompensAmpl_COMP_3P6PF   | (uint8)( CurrCompensAmpl_REDC_11 >> 2 )), /* G=24 */
        ( CurrCompensAmpl_COMP_3P6PF   | (uint8)( CurrCompensAmpl_REDC_11 >> 2 )), /* G=32 */
        ( CurrCompensAmpl_COMP_3P6PF   | (uint8)( CurrCompensAmpl_REDC_00 >> 2 )), /* G=48 */
        ( CurrCompensAmpl_COMP_3P6PF   | (uint8)( CurrCompensAmpl_REDC_00 >> 2 ))  /* G=50 */
    };
    
    /* Only set new gain if it is a valid gain */
    if( gain <= CurrCompensAmpl_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        CurrCompensAmpl_CR2_REG &= (uint8)(~(CurrCompensAmpl_RVAL_MASK | CurrCompensAmpl_R20_40B_MASK | 
                                CurrCompensAmpl_REDC_MASK | CurrCompensAmpl_BIAS_MASK ));

        /* Set gain value resistors, redc comp, and bias */
        CurrCompensAmpl_CR2_REG |= (CurrCompensAmpl_GainArray[gain] |
                                ((uint8)(CurrCompensAmpl_GainComp[gain] << 2 ) & CurrCompensAmpl_REDC_MASK));

        /* Clear sc_comp  */
        CurrCompensAmpl_CR1_REG &= (uint8)(~CurrCompensAmpl_COMP_MASK);
        /* Set sc_comp  */
        CurrCompensAmpl_CR1_REG |= ( CurrCompensAmpl_GainComp[gain] | CurrCompensAmpl_COMP_MASK );
    }
}


/* [] END OF FILE */
