/*******************************************************************************
* File Name: DAC_OutCtrl.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the DVDAC component.
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_DVDAC_DAC_OutCtrl_H)
#define CY_DVDAC_DAC_OutCtrl_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Data Struct Definition
***************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} DAC_OutCtrl_BACKUP_STRUCT;

/* Component init state */
extern uint8 DAC_OutCtrl_initVar;


/***************************************
*        API constants
***************************************/
#define DAC_OutCtrl_RESOLUTION                 (12u)
#define DAC_OutCtrl_INTERNAL_CLOCK_USED        (1u)

#define DAC_OutCtrl_INTEGER_PORTION_SHIFT      (DAC_OutCtrl_RESOLUTION - 8u)
#define DAC_OutCtrl_DITHERED_ARRAY_SIZE        ((uint8)(1u << DAC_OutCtrl_INTEGER_PORTION_SHIFT))
#define DAC_OutCtrl_FRACTIONAL_PORTION_MASK    (DAC_OutCtrl_DITHERED_ARRAY_SIZE - 1u)
#define DAC_OutCtrl_INTEGER_PORTION_MAX_VALUE  (0xFFu)

/* DMA Configuration */
#define DAC_OutCtrl_DMA_BYTES_PER_BURST        (1u)
#define DAC_OutCtrl_DMA_REQUEST_PER_BURST      (1u)
#define DAC_OutCtrl_DMA_SRC_BASE               (CYDEV_SRAM_BASE)
#define DAC_OutCtrl_DMA_DST_BASE               (CYDEV_PERIPH_BASE)


#if   (DAC_OutCtrl_RESOLUTION ==  9u)
    #define DAC_OutCtrl_DVDAC_MAX_VALUE        (0x1FEu)
#elif (DAC_OutCtrl_RESOLUTION == 10u)
    #define DAC_OutCtrl_DVDAC_MAX_VALUE        (0x3FCu)
#elif (DAC_OutCtrl_RESOLUTION == 11u)
    #define DAC_OutCtrl_DVDAC_MAX_VALUE        (0x7F8u)
#else   /* Resolution 12 bits */
    #define DAC_OutCtrl_DVDAC_MAX_VALUE        (0xFF0u)
#endif  /* (DAC_OutCtrl_RESOLUTION ==  9u) */


/***************************************
*        Function Prototypes
***************************************/

void DAC_OutCtrl_Init(void)                ;
void DAC_OutCtrl_Enable(void)              ;
void DAC_OutCtrl_Start(void)               ;
void DAC_OutCtrl_Stop(void)                ;
void DAC_OutCtrl_SetValue(uint16 value)    ;
void DAC_OutCtrl_Sleep(void)               ;
void DAC_OutCtrl_Wakeup(void)              ;
void DAC_OutCtrl_SaveConfig(void)          ;
void DAC_OutCtrl_RestoreConfig(void)       ;

#endif /* CY_DVDAC_DAC_OutCtrl_H */


/* [] END OF FILE */
