/*******************************************************************************
* File Name: FAN_TCH.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "FAN_TCH.h"


/*******************************************************************************
* Function Name: FAN_TCH_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void FAN_TCH_Write(uint8 value) 
{
    uint8 staticBits = (FAN_TCH_DR & (uint8)(~FAN_TCH_MASK));
    FAN_TCH_DR = staticBits | ((uint8)(value << FAN_TCH_SHIFT) & FAN_TCH_MASK);
}


/*******************************************************************************
* Function Name: FAN_TCH_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  FAN_TCH_DM_STRONG     Strong Drive 
*  FAN_TCH_DM_OD_HI      Open Drain, Drives High 
*  FAN_TCH_DM_OD_LO      Open Drain, Drives Low 
*  FAN_TCH_DM_RES_UP     Resistive Pull Up 
*  FAN_TCH_DM_RES_DWN    Resistive Pull Down 
*  FAN_TCH_DM_RES_UPDWN  Resistive Pull Up/Down 
*  FAN_TCH_DM_DIG_HIZ    High Impedance Digital 
*  FAN_TCH_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void FAN_TCH_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(FAN_TCH_0, mode);
}


/*******************************************************************************
* Function Name: FAN_TCH_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro FAN_TCH_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 FAN_TCH_Read(void) 
{
    return (FAN_TCH_PS & FAN_TCH_MASK) >> FAN_TCH_SHIFT;
}


/*******************************************************************************
* Function Name: FAN_TCH_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 FAN_TCH_ReadDataReg(void) 
{
    return (FAN_TCH_DR & FAN_TCH_MASK) >> FAN_TCH_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(FAN_TCH_INTSTAT) 

    /*******************************************************************************
    * Function Name: FAN_TCH_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 FAN_TCH_ClearInterrupt(void) 
    {
        return (FAN_TCH_INTSTAT & FAN_TCH_MASK) >> FAN_TCH_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
