/*******************************************************************************
* File Name: KeyStatus_Gr0_4s.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "KeyStatus_Gr0_4s.h"

#if !defined(KeyStatus_Gr0_4s_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: KeyStatus_Gr0_4s_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 KeyStatus_Gr0_4s_Read(void) 
{ 
    return KeyStatus_Gr0_4s_Status;
}


/*******************************************************************************
* Function Name: KeyStatus_Gr0_4s_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void KeyStatus_Gr0_4s_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    KeyStatus_Gr0_4s_Status_Aux_Ctrl |= KeyStatus_Gr0_4s_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: KeyStatus_Gr0_4s_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void KeyStatus_Gr0_4s_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    KeyStatus_Gr0_4s_Status_Aux_Ctrl &= (uint8)(~KeyStatus_Gr0_4s_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: KeyStatus_Gr0_4s_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void KeyStatus_Gr0_4s_WriteMask(uint8 mask) 
{
    #if(KeyStatus_Gr0_4s_INPUTS < 8u)
    	mask &= (uint8)((((uint8)1u) << KeyStatus_Gr0_4s_INPUTS) - 1u);
	#endif /* End KeyStatus_Gr0_4s_INPUTS < 8u */
    KeyStatus_Gr0_4s_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: KeyStatus_Gr0_4s_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 KeyStatus_Gr0_4s_ReadMask(void) 
{
    return KeyStatus_Gr0_4s_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
