/*******************************************************************************
* File Name: MAIN_PWR.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MAIN_PWR.h"


/*******************************************************************************
* Function Name: MAIN_PWR_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void MAIN_PWR_Write(uint8 value) 
{
    uint8 staticBits = (MAIN_PWR_DR & (uint8)(~MAIN_PWR_MASK));
    MAIN_PWR_DR = staticBits | ((uint8)(value << MAIN_PWR_SHIFT) & MAIN_PWR_MASK);
}


/*******************************************************************************
* Function Name: MAIN_PWR_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  MAIN_PWR_DM_STRONG     Strong Drive 
*  MAIN_PWR_DM_OD_HI      Open Drain, Drives High 
*  MAIN_PWR_DM_OD_LO      Open Drain, Drives Low 
*  MAIN_PWR_DM_RES_UP     Resistive Pull Up 
*  MAIN_PWR_DM_RES_DWN    Resistive Pull Down 
*  MAIN_PWR_DM_RES_UPDWN  Resistive Pull Up/Down 
*  MAIN_PWR_DM_DIG_HIZ    High Impedance Digital 
*  MAIN_PWR_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void MAIN_PWR_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MAIN_PWR_0, mode);
}


/*******************************************************************************
* Function Name: MAIN_PWR_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MAIN_PWR_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MAIN_PWR_Read(void) 
{
    return (MAIN_PWR_PS & MAIN_PWR_MASK) >> MAIN_PWR_SHIFT;
}


/*******************************************************************************
* Function Name: MAIN_PWR_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MAIN_PWR_ReadDataReg(void) 
{
    return (MAIN_PWR_DR & MAIN_PWR_MASK) >> MAIN_PWR_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MAIN_PWR_INTSTAT) 

    /*******************************************************************************
    * Function Name: MAIN_PWR_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MAIN_PWR_ClearInterrupt(void) 
    {
        return (MAIN_PWR_INTSTAT & MAIN_PWR_MASK) >> MAIN_PWR_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
