/*******************************************************************************
* File Name: MouseClk.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MouseClk.h"


/*******************************************************************************
* Function Name: MouseClk_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void MouseClk_Write(uint8 value) 
{
    uint8 staticBits = (MouseClk_DR & (uint8)(~MouseClk_MASK));
    MouseClk_DR = staticBits | ((uint8)(value << MouseClk_SHIFT) & MouseClk_MASK);
}


/*******************************************************************************
* Function Name: MouseClk_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  MouseClk_DM_STRONG     Strong Drive 
*  MouseClk_DM_OD_HI      Open Drain, Drives High 
*  MouseClk_DM_OD_LO      Open Drain, Drives Low 
*  MouseClk_DM_RES_UP     Resistive Pull Up 
*  MouseClk_DM_RES_DWN    Resistive Pull Down 
*  MouseClk_DM_RES_UPDWN  Resistive Pull Up/Down 
*  MouseClk_DM_DIG_HIZ    High Impedance Digital 
*  MouseClk_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void MouseClk_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MouseClk_0, mode);
}


/*******************************************************************************
* Function Name: MouseClk_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MouseClk_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MouseClk_Read(void) 
{
    return (MouseClk_PS & MouseClk_MASK) >> MouseClk_SHIFT;
}


/*******************************************************************************
* Function Name: MouseClk_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MouseClk_ReadDataReg(void) 
{
    return (MouseClk_DR & MouseClk_MASK) >> MouseClk_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MouseClk_INTSTAT) 

    /*******************************************************************************
    * Function Name: MouseClk_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MouseClk_ClearInterrupt(void) 
    {
        return (MouseClk_INTSTAT & MouseClk_MASK) >> MouseClk_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
