/*******************************************************************************
* File Name: MouseData.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MouseData.h"


/*******************************************************************************
* Function Name: MouseData_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void MouseData_Write(uint8 value) 
{
    uint8 staticBits = (MouseData_DR & (uint8)(~MouseData_MASK));
    MouseData_DR = staticBits | ((uint8)(value << MouseData_SHIFT) & MouseData_MASK);
}


/*******************************************************************************
* Function Name: MouseData_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  MouseData_DM_STRONG     Strong Drive 
*  MouseData_DM_OD_HI      Open Drain, Drives High 
*  MouseData_DM_OD_LO      Open Drain, Drives Low 
*  MouseData_DM_RES_UP     Resistive Pull Up 
*  MouseData_DM_RES_DWN    Resistive Pull Down 
*  MouseData_DM_RES_UPDWN  Resistive Pull Up/Down 
*  MouseData_DM_DIG_HIZ    High Impedance Digital 
*  MouseData_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void MouseData_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MouseData_0, mode);
}


/*******************************************************************************
* Function Name: MouseData_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MouseData_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MouseData_Read(void) 
{
    return (MouseData_PS & MouseData_MASK) >> MouseData_SHIFT;
}


/*******************************************************************************
* Function Name: MouseData_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MouseData_ReadDataReg(void) 
{
    return (MouseData_DR & MouseData_MASK) >> MouseData_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MouseData_INTSTAT) 

    /*******************************************************************************
    * Function Name: MouseData_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MouseData_ClearInterrupt(void) 
    {
        return (MouseData_INTSTAT & MouseData_MASK) >> MouseData_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
