/*******************************************************************************
* File Name: MouseISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include <cydevice_trm.h>
#include <CyLib.h>
#include <MouseISR.h>

#if !defined(MouseISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START MouseISR_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: MouseISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_Start(void) 
{
    /* For all we know the interrupt is active. */
    MouseISR_Disable();

    /* Set the ISR to point to the MouseISR Interrupt. */
    MouseISR_SetVector(&MouseISR_Interrupt);

    /* Set the priority. */
    MouseISR_SetPriority((uint8)MouseISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    MouseISR_Enable();
}


/*******************************************************************************
* Function Name: MouseISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_StartEx(cyisraddress address) 
{
    /* For all we know the interrupt is active. */
    MouseISR_Disable();

    /* Set the ISR to point to the MouseISR Interrupt. */
    MouseISR_SetVector(address);

    /* Set the priority. */
    MouseISR_SetPriority((uint8)MouseISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    MouseISR_Enable();
}


/*******************************************************************************
* Function Name: MouseISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_Stop(void) 
{
    /* Disable this interrupt. */
    MouseISR_Disable();
}


/*******************************************************************************
* Function Name: MouseISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for MouseISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(MouseISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START MouseISR_Interrupt` */

    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (MouseISR__ES2_PATCH ))      
            MouseISR_ISR_PATCH();
        #endif /* CYDEV_CHIP_REVISION_USED */
    #endif /* (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */
}


/*******************************************************************************
* Function Name: MouseISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling MouseISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use MouseISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_SetVector(cyisraddress address) 
{
    CY_SET_REG16(MouseISR_INTC_VECTOR, (uint16) address);
}


/*******************************************************************************
* Function Name: MouseISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress MouseISR_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(MouseISR_INTC_VECTOR);
}


/*******************************************************************************
* Function Name: MouseISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling MouseISR_Start
*   or MouseISR_StartEx will override any effect this method would 
*   have had. This method should only be called after MouseISR_Start or 
*   MouseISR_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_SetPriority(uint8 priority) 
{
    *MouseISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: MouseISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 MouseISR_GetPriority(void) 
{
    uint8 priority;


    priority = *MouseISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: MouseISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_Enable(void) 
{
    /* Enable the general interrupt. */
    *MouseISR_INTC_SET_EN = MouseISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: MouseISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 MouseISR_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return ((*MouseISR_INTC_SET_EN & (uint8)MouseISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: MouseISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_Disable(void) 
{
    /* Disable the general interrupt. */
    *MouseISR_INTC_CLR_EN = MouseISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: MouseISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_SetPending(void) 
{
    *MouseISR_INTC_SET_PD = MouseISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: MouseISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void MouseISR_ClearPending(void) 
{
    *MouseISR_INTC_CLR_PD = MouseISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
