/*******************************************************************************
* File Name: OUT_DISCH.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "OUT_DISCH.h"


/*******************************************************************************
* Function Name: OUT_DISCH_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void OUT_DISCH_Write(uint8 value) 
{
    uint8 staticBits = (OUT_DISCH_DR & (uint8)(~OUT_DISCH_MASK));
    OUT_DISCH_DR = staticBits | ((uint8)(value << OUT_DISCH_SHIFT) & OUT_DISCH_MASK);
}


/*******************************************************************************
* Function Name: OUT_DISCH_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  OUT_DISCH_DM_STRONG     Strong Drive 
*  OUT_DISCH_DM_OD_HI      Open Drain, Drives High 
*  OUT_DISCH_DM_OD_LO      Open Drain, Drives Low 
*  OUT_DISCH_DM_RES_UP     Resistive Pull Up 
*  OUT_DISCH_DM_RES_DWN    Resistive Pull Down 
*  OUT_DISCH_DM_RES_UPDWN  Resistive Pull Up/Down 
*  OUT_DISCH_DM_DIG_HIZ    High Impedance Digital 
*  OUT_DISCH_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void OUT_DISCH_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OUT_DISCH_0, mode);
}


/*******************************************************************************
* Function Name: OUT_DISCH_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OUT_DISCH_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OUT_DISCH_Read(void) 
{
    return (OUT_DISCH_PS & OUT_DISCH_MASK) >> OUT_DISCH_SHIFT;
}


/*******************************************************************************
* Function Name: OUT_DISCH_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OUT_DISCH_ReadDataReg(void) 
{
    return (OUT_DISCH_DR & OUT_DISCH_MASK) >> OUT_DISCH_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OUT_DISCH_INTSTAT) 

    /*******************************************************************************
    * Function Name: OUT_DISCH_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OUT_DISCH_ClearInterrupt(void) 
    {
        return (OUT_DISCH_INTSTAT & OUT_DISCH_MASK) >> OUT_DISCH_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
