/*******************************************************************************
* File Name: OUT_ON_S.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "OUT_ON_S.h"


/*******************************************************************************
* Function Name: OUT_ON_S_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void OUT_ON_S_Write(uint8 value) 
{
    uint8 staticBits = (OUT_ON_S_DR & (uint8)(~OUT_ON_S_MASK));
    OUT_ON_S_DR = staticBits | ((uint8)(value << OUT_ON_S_SHIFT) & OUT_ON_S_MASK);
}


/*******************************************************************************
* Function Name: OUT_ON_S_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  OUT_ON_S_DM_STRONG     Strong Drive 
*  OUT_ON_S_DM_OD_HI      Open Drain, Drives High 
*  OUT_ON_S_DM_OD_LO      Open Drain, Drives Low 
*  OUT_ON_S_DM_RES_UP     Resistive Pull Up 
*  OUT_ON_S_DM_RES_DWN    Resistive Pull Down 
*  OUT_ON_S_DM_RES_UPDWN  Resistive Pull Up/Down 
*  OUT_ON_S_DM_DIG_HIZ    High Impedance Digital 
*  OUT_ON_S_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void OUT_ON_S_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OUT_ON_S_0, mode);
}


/*******************************************************************************
* Function Name: OUT_ON_S_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OUT_ON_S_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OUT_ON_S_Read(void) 
{
    return (OUT_ON_S_PS & OUT_ON_S_MASK) >> OUT_ON_S_SHIFT;
}


/*******************************************************************************
* Function Name: OUT_ON_S_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OUT_ON_S_ReadDataReg(void) 
{
    return (OUT_ON_S_DR & OUT_ON_S_MASK) >> OUT_ON_S_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OUT_ON_S_INTSTAT) 

    /*******************************************************************************
    * Function Name: OUT_ON_S_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OUT_ON_S_ClearInterrupt(void) 
    {
        return (OUT_ON_S_INTSTAT & OUT_ON_S_MASK) >> OUT_ON_S_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
