/*******************************************************************************
* File Name: OutCurrAmpl_1.c  
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OutCurrAmpl_1.h"

#if (!CY_PSOC5A)
    #if (CYDEV_VARIABLE_VDDA == 1u)
        #include "CyScBoostClk.h"
    #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
#endif /* (!CY_PSOC5A) */

#if (CY_PSOC5A)
    static OutCurrAmpl_1_BACKUP_STRUCT  OutCurrAmpl_1_P5backup;
#endif /* (CY_ PSOC5A) */

uint8 OutCurrAmpl_1_initVar = 0u;


/*******************************************************************************   
* Function Name: OutCurrAmpl_1_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  OutCurrAmpl_1_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutCurrAmpl_1_Init(void) 
{
    /* Set PGA mode */
    OutCurrAmpl_1_CR0_REG = OutCurrAmpl_1_MODE_PGA;      
    /* Set non-inverting PGA mode and reference mode */
    OutCurrAmpl_1_CR1_REG |= OutCurrAmpl_1_PGA_NINV;  
    /* Set default gain and ref mode */
    OutCurrAmpl_1_CR2_REG = OutCurrAmpl_1_VREF_MODE;
    /* Set gain and compensation */
    OutCurrAmpl_1_SetGain(OutCurrAmpl_1_DEFAULT_GAIN);
    /* Set power */
    OutCurrAmpl_1_SetPower(OutCurrAmpl_1_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: OutCurrAmpl_1_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutCurrAmpl_1_Enable(void) 
{
    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modifications in stop() API */
    #if (CY_PSOC5A)
        if(OutCurrAmpl_1_P5backup.enableState == 1u)
        {
            OutCurrAmpl_1_CR1_REG = OutCurrAmpl_1_P5backup.scCR1Reg;
            OutCurrAmpl_1_CR2_REG = OutCurrAmpl_1_P5backup.scCR2Reg;
            OutCurrAmpl_1_P5backup.enableState = 0u;
        }
    #endif /* CY_PSOC5A */   

    /* Enable power to the Amp in Active mode*/
    OutCurrAmpl_1_PM_ACT_CFG_REG |= OutCurrAmpl_1_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    OutCurrAmpl_1_PM_STBY_CFG_REG |= OutCurrAmpl_1_STBY_PWR_EN;
    
    OutCurrAmpl_1_PUMP_CR1_REG |= OutCurrAmpl_1_PUMP_CR1_SC_CLKSEL;
    
    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            if(CyScPumpEnabled == 1u)
            {
                OutCurrAmpl_1_BSTCLK_REG &= (uint8)(~OutCurrAmpl_1_BST_CLK_INDEX_MASK);
                OutCurrAmpl_1_BSTCLK_REG |= OutCurrAmpl_1_BST_CLK_EN | CyScBoostClk__INDEX;
                OutCurrAmpl_1_SC_MISC_REG |= OutCurrAmpl_1_PUMP_FORCE;
                CyScBoostClk_Start();
            }
            else
            {
                OutCurrAmpl_1_BSTCLK_REG &= (uint8)(~OutCurrAmpl_1_BST_CLK_EN);
                OutCurrAmpl_1_SC_MISC_REG &= (uint8)(~OutCurrAmpl_1_PUMP_FORCE);
            }
        #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
    #endif /* (!CY_PSOC5A) */
}


/*******************************************************************************
* Function Name: OutCurrAmpl_1_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutCurrAmpl_1_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(OutCurrAmpl_1_initVar == 0u)
    {
        OutCurrAmpl_1_Init();
        OutCurrAmpl_1_initVar = 1u;
    }

    OutCurrAmpl_1_Enable();
}


/*******************************************************************************
* Function Name: OutCurrAmpl_1_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutCurrAmpl_1_Stop(void) 
{ 
    /* Disble power to the Amp in Active mode template */
    OutCurrAmpl_1_PM_ACT_CFG_REG &= (uint8)(~OutCurrAmpl_1_ACT_PWR_EN);

    /* Disble power to the Amp in Alternative Active mode template */
    OutCurrAmpl_1_PM_STBY_CFG_REG &= (uint8)(~OutCurrAmpl_1_STBY_PWR_EN);

    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            OutCurrAmpl_1_BSTCLK_REG &= (uint8)(~OutCurrAmpl_1_BST_CLK_EN);
            /* Disable pumps only if there aren't any SC block in use */
            if ((OutCurrAmpl_1_PM_ACT_CFG_REG & OutCurrAmpl_1_PM_ACT_CFG_MASK) == 0u)
            {
                OutCurrAmpl_1_SC_MISC_REG &= (uint8)(~OutCurrAmpl_1_PUMP_FORCE);
                OutCurrAmpl_1_PUMP_CR1_REG &= (uint8)(~OutCurrAmpl_1_PUMP_CR1_SC_CLKSEL);
                CyScBoostClk_Stop();
            }
        #endif /* CYDEV_VARIABLE_VDDA == 1u */
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        OutCurrAmpl_1_P5backup.scCR1Reg = OutCurrAmpl_1_CR1_REG;
        OutCurrAmpl_1_P5backup.scCR2Reg = OutCurrAmpl_1_CR2_REG;
        OutCurrAmpl_1_CR1_REG = 0x00u;
        OutCurrAmpl_1_CR2_REG = 0x00u;
        OutCurrAmpl_1_P5backup.enableState = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: OutCurrAmpl_1_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void OutCurrAmpl_1_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = OutCurrAmpl_1_CR1_REG & (uint8)(~OutCurrAmpl_1_DRIVE_MASK);
    tmpCR |= (power & OutCurrAmpl_1_DRIVE_MASK);
    OutCurrAmpl_1_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: OutCurrAmpl_1_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void OutCurrAmpl_1_SetGain(uint8 gain) 
{
    /* Constant array for gain settings */
    const uint8 OutCurrAmpl_1_GainArray[9] = { 
        (OutCurrAmpl_1_RVAL_0K   | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=1  */
        (OutCurrAmpl_1_RVAL_40K  | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=2  */
        (OutCurrAmpl_1_RVAL_120K | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=4  */
        (OutCurrAmpl_1_RVAL_280K | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=8  */
        (OutCurrAmpl_1_RVAL_600K | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=16 */
        (OutCurrAmpl_1_RVAL_460K | OutCurrAmpl_1_R20_40B_40K | OutCurrAmpl_1_BIAS_LOW), /* G=24, Sets Rin as 20k */
        (OutCurrAmpl_1_RVAL_620K | OutCurrAmpl_1_R20_40B_20K | OutCurrAmpl_1_BIAS_LOW), /* G=32 */
        (OutCurrAmpl_1_RVAL_470K | OutCurrAmpl_1_R20_40B_20K | OutCurrAmpl_1_BIAS_LOW), /* G=48, Sets Rin as 10k */
        (OutCurrAmpl_1_RVAL_490K | OutCurrAmpl_1_R20_40B_20K | OutCurrAmpl_1_BIAS_LOW)  /* G=50, Sets Rin as 10k */
    };
    
    /* Constant array for gain compenstion settings */
    const uint8 OutCurrAmpl_1_GainComp[9] = { 
        ( OutCurrAmpl_1_COMP_4P35PF  | (uint8)( OutCurrAmpl_1_REDC_00 >> 2 )), /* G=1  */
        ( OutCurrAmpl_1_COMP_4P35PF  | (uint8)( OutCurrAmpl_1_REDC_01 >> 2 )), /* G=2  */
        ( OutCurrAmpl_1_COMP_3P0PF   | (uint8)( OutCurrAmpl_1_REDC_01 >> 2 )), /* G=4  */
        ( OutCurrAmpl_1_COMP_3P0PF   | (uint8)( OutCurrAmpl_1_REDC_01 >> 2 )), /* G=8  */
        ( OutCurrAmpl_1_COMP_3P6PF   | (uint8)( OutCurrAmpl_1_REDC_01 >> 2 )), /* G=16 */
        ( OutCurrAmpl_1_COMP_3P6PF   | (uint8)( OutCurrAmpl_1_REDC_11 >> 2 )), /* G=24 */
        ( OutCurrAmpl_1_COMP_3P6PF   | (uint8)( OutCurrAmpl_1_REDC_11 >> 2 )), /* G=32 */
        ( OutCurrAmpl_1_COMP_3P6PF   | (uint8)( OutCurrAmpl_1_REDC_00 >> 2 )), /* G=48 */
        ( OutCurrAmpl_1_COMP_3P6PF   | (uint8)( OutCurrAmpl_1_REDC_00 >> 2 ))  /* G=50 */
    };
    
    /* Only set new gain if it is a valid gain */
    if( gain <= OutCurrAmpl_1_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        OutCurrAmpl_1_CR2_REG &= (uint8)(~(OutCurrAmpl_1_RVAL_MASK | OutCurrAmpl_1_R20_40B_MASK | 
                                OutCurrAmpl_1_REDC_MASK | OutCurrAmpl_1_BIAS_MASK ));

        /* Set gain value resistors, redc comp, and bias */
        OutCurrAmpl_1_CR2_REG |= (OutCurrAmpl_1_GainArray[gain] |
                                ((uint8)(OutCurrAmpl_1_GainComp[gain] << 2 ) & OutCurrAmpl_1_REDC_MASK));

        /* Clear sc_comp  */
        OutCurrAmpl_1_CR1_REG &= (uint8)(~OutCurrAmpl_1_COMP_MASK);
        /* Set sc_comp  */
        OutCurrAmpl_1_CR1_REG |= ( OutCurrAmpl_1_GainComp[gain] | OutCurrAmpl_1_COMP_MASK );
    }
}


/* [] END OF FILE */
