/*******************************************************************************
* File Name: OutCurr_MN.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "OutCurr_MN.h"


/*******************************************************************************
* Function Name: OutCurr_MN_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void OutCurr_MN_Write(uint8 value) 
{
    uint8 staticBits = (OutCurr_MN_DR & (uint8)(~OutCurr_MN_MASK));
    OutCurr_MN_DR = staticBits | ((uint8)(value << OutCurr_MN_SHIFT) & OutCurr_MN_MASK);
}


/*******************************************************************************
* Function Name: OutCurr_MN_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  OutCurr_MN_DM_STRONG     Strong Drive 
*  OutCurr_MN_DM_OD_HI      Open Drain, Drives High 
*  OutCurr_MN_DM_OD_LO      Open Drain, Drives Low 
*  OutCurr_MN_DM_RES_UP     Resistive Pull Up 
*  OutCurr_MN_DM_RES_DWN    Resistive Pull Down 
*  OutCurr_MN_DM_RES_UPDWN  Resistive Pull Up/Down 
*  OutCurr_MN_DM_DIG_HIZ    High Impedance Digital 
*  OutCurr_MN_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void OutCurr_MN_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OutCurr_MN_0, mode);
}


/*******************************************************************************
* Function Name: OutCurr_MN_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OutCurr_MN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OutCurr_MN_Read(void) 
{
    return (OutCurr_MN_PS & OutCurr_MN_MASK) >> OutCurr_MN_SHIFT;
}


/*******************************************************************************
* Function Name: OutCurr_MN_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OutCurr_MN_ReadDataReg(void) 
{
    return (OutCurr_MN_DR & OutCurr_MN_MASK) >> OutCurr_MN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OutCurr_MN_INTSTAT) 

    /*******************************************************************************
    * Function Name: OutCurr_MN_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OutCurr_MN_ClearInterrupt(void) 
    {
        return (OutCurr_MN_INTSTAT & OutCurr_MN_MASK) >> OutCurr_MN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
