/*******************************************************************************
* File Name: OutVoltAmpl.c  
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OutVoltAmpl.h"

#if (!CY_PSOC5A)
    #if (CYDEV_VARIABLE_VDDA == 1u)
        #include "CyScBoostClk.h"
    #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
#endif /* (!CY_PSOC5A) */

#if (CY_PSOC5A)
    static OutVoltAmpl_BACKUP_STRUCT  OutVoltAmpl_P5backup;
#endif /* (CY_ PSOC5A) */

uint8 OutVoltAmpl_initVar = 0u;


/*******************************************************************************   
* Function Name: OutVoltAmpl_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  OutVoltAmpl_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutVoltAmpl_Init(void) 
{
    /* Set PGA mode */
    OutVoltAmpl_CR0_REG = OutVoltAmpl_MODE_PGA;      
    /* Set non-inverting PGA mode and reference mode */
    OutVoltAmpl_CR1_REG |= OutVoltAmpl_PGA_NINV;  
    /* Set default gain and ref mode */
    OutVoltAmpl_CR2_REG = OutVoltAmpl_VREF_MODE;
    /* Set gain and compensation */
    OutVoltAmpl_SetGain(OutVoltAmpl_DEFAULT_GAIN);
    /* Set power */
    OutVoltAmpl_SetPower(OutVoltAmpl_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: OutVoltAmpl_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutVoltAmpl_Enable(void) 
{
    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modifications in stop() API */
    #if (CY_PSOC5A)
        if(OutVoltAmpl_P5backup.enableState == 1u)
        {
            OutVoltAmpl_CR1_REG = OutVoltAmpl_P5backup.scCR1Reg;
            OutVoltAmpl_CR2_REG = OutVoltAmpl_P5backup.scCR2Reg;
            OutVoltAmpl_P5backup.enableState = 0u;
        }
    #endif /* CY_PSOC5A */   

    /* Enable power to the Amp in Active mode*/
    OutVoltAmpl_PM_ACT_CFG_REG |= OutVoltAmpl_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    OutVoltAmpl_PM_STBY_CFG_REG |= OutVoltAmpl_STBY_PWR_EN;
    
    OutVoltAmpl_PUMP_CR1_REG |= OutVoltAmpl_PUMP_CR1_SC_CLKSEL;
    
    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            if(CyScPumpEnabled == 1u)
            {
                OutVoltAmpl_BSTCLK_REG &= (uint8)(~OutVoltAmpl_BST_CLK_INDEX_MASK);
                OutVoltAmpl_BSTCLK_REG |= OutVoltAmpl_BST_CLK_EN | CyScBoostClk__INDEX;
                OutVoltAmpl_SC_MISC_REG |= OutVoltAmpl_PUMP_FORCE;
                CyScBoostClk_Start();
            }
            else
            {
                OutVoltAmpl_BSTCLK_REG &= (uint8)(~OutVoltAmpl_BST_CLK_EN);
                OutVoltAmpl_SC_MISC_REG &= (uint8)(~OutVoltAmpl_PUMP_FORCE);
            }
        #endif /* (CYDEV_VARIABLE_VDDA == 1u) */
    #endif /* (!CY_PSOC5A) */
}


/*******************************************************************************
* Function Name: OutVoltAmpl_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values and sets
*  the power to the given level. A power level of 0, is same as executing
*  the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutVoltAmpl_Start(void) 
{

    /* This is to restore the value of register CR1 and CR2 which is saved 
      in prior to the modification in stop() API */

    if(OutVoltAmpl_initVar == 0u)
    {
        OutVoltAmpl_Init();
        OutVoltAmpl_initVar = 1u;
    }

    OutVoltAmpl_Enable();
}


/*******************************************************************************
* Function Name: OutVoltAmpl_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OutVoltAmpl_Stop(void) 
{ 
    /* Disble power to the Amp in Active mode template */
    OutVoltAmpl_PM_ACT_CFG_REG &= (uint8)(~OutVoltAmpl_ACT_PWR_EN);

    /* Disble power to the Amp in Alternative Active mode template */
    OutVoltAmpl_PM_STBY_CFG_REG &= (uint8)(~OutVoltAmpl_STBY_PWR_EN);

    #if (!CY_PSOC5A)
        #if (CYDEV_VARIABLE_VDDA == 1u)
            OutVoltAmpl_BSTCLK_REG &= (uint8)(~OutVoltAmpl_BST_CLK_EN);
            /* Disable pumps only if there aren't any SC block in use */
            if ((OutVoltAmpl_PM_ACT_CFG_REG & OutVoltAmpl_PM_ACT_CFG_MASK) == 0u)
            {
                OutVoltAmpl_SC_MISC_REG &= (uint8)(~OutVoltAmpl_PUMP_FORCE);
                OutVoltAmpl_PUMP_CR1_REG &= (uint8)(~OutVoltAmpl_PUMP_CR1_SC_CLKSEL);
                CyScBoostClk_Stop();
            }
        #endif /* CYDEV_VARIABLE_VDDA == 1u */
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /* This sets PGA in zero current mode and output routes are valid */
    #if (CY_PSOC5A)
        OutVoltAmpl_P5backup.scCR1Reg = OutVoltAmpl_CR1_REG;
        OutVoltAmpl_P5backup.scCR2Reg = OutVoltAmpl_CR2_REG;
        OutVoltAmpl_CR1_REG = 0x00u;
        OutVoltAmpl_CR2_REG = 0x00u;
        OutVoltAmpl_P5backup.enableState = 1u;
    #endif /* CY_PSOC5A */
}


/*******************************************************************************
* Function Name: OutVoltAmpl_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA.
*
* Parameters:
*  power: Sets power level between (0) and (3) high power
*
* Return:
*  void
*
*******************************************************************************/
void OutVoltAmpl_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = OutVoltAmpl_CR1_REG & (uint8)(~OutVoltAmpl_DRIVE_MASK);
    tmpCR |= (power & OutVoltAmpl_DRIVE_MASK);
    OutVoltAmpl_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: OutVoltAmpl_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:
*  gain: Gain value of PGA (See header file for gain values.)
*
* Return:
*  void 
*
*******************************************************************************/
void OutVoltAmpl_SetGain(uint8 gain) 
{
    /* Constant array for gain settings */
    const uint8 OutVoltAmpl_GainArray[9] = { 
        (OutVoltAmpl_RVAL_0K   | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=1  */
        (OutVoltAmpl_RVAL_40K  | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=2  */
        (OutVoltAmpl_RVAL_120K | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=4  */
        (OutVoltAmpl_RVAL_280K | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=8  */
        (OutVoltAmpl_RVAL_600K | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=16 */
        (OutVoltAmpl_RVAL_460K | OutVoltAmpl_R20_40B_40K | OutVoltAmpl_BIAS_LOW), /* G=24, Sets Rin as 20k */
        (OutVoltAmpl_RVAL_620K | OutVoltAmpl_R20_40B_20K | OutVoltAmpl_BIAS_LOW), /* G=32 */
        (OutVoltAmpl_RVAL_470K | OutVoltAmpl_R20_40B_20K | OutVoltAmpl_BIAS_LOW), /* G=48, Sets Rin as 10k */
        (OutVoltAmpl_RVAL_490K | OutVoltAmpl_R20_40B_20K | OutVoltAmpl_BIAS_LOW)  /* G=50, Sets Rin as 10k */
    };
    
    /* Constant array for gain compenstion settings */
    const uint8 OutVoltAmpl_GainComp[9] = { 
        ( OutVoltAmpl_COMP_4P35PF  | (uint8)( OutVoltAmpl_REDC_00 >> 2 )), /* G=1  */
        ( OutVoltAmpl_COMP_4P35PF  | (uint8)( OutVoltAmpl_REDC_01 >> 2 )), /* G=2  */
        ( OutVoltAmpl_COMP_3P0PF   | (uint8)( OutVoltAmpl_REDC_01 >> 2 )), /* G=4  */
        ( OutVoltAmpl_COMP_3P0PF   | (uint8)( OutVoltAmpl_REDC_01 >> 2 )), /* G=8  */
        ( OutVoltAmpl_COMP_3P6PF   | (uint8)( OutVoltAmpl_REDC_01 >> 2 )), /* G=16 */
        ( OutVoltAmpl_COMP_3P6PF   | (uint8)( OutVoltAmpl_REDC_11 >> 2 )), /* G=24 */
        ( OutVoltAmpl_COMP_3P6PF   | (uint8)( OutVoltAmpl_REDC_11 >> 2 )), /* G=32 */
        ( OutVoltAmpl_COMP_3P6PF   | (uint8)( OutVoltAmpl_REDC_00 >> 2 )), /* G=48 */
        ( OutVoltAmpl_COMP_3P6PF   | (uint8)( OutVoltAmpl_REDC_00 >> 2 ))  /* G=50 */
    };
    
    /* Only set new gain if it is a valid gain */
    if( gain <= OutVoltAmpl_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        OutVoltAmpl_CR2_REG &= (uint8)(~(OutVoltAmpl_RVAL_MASK | OutVoltAmpl_R20_40B_MASK | 
                                OutVoltAmpl_REDC_MASK | OutVoltAmpl_BIAS_MASK ));

        /* Set gain value resistors, redc comp, and bias */
        OutVoltAmpl_CR2_REG |= (OutVoltAmpl_GainArray[gain] |
                                ((uint8)(OutVoltAmpl_GainComp[gain] << 2 ) & OutVoltAmpl_REDC_MASK));

        /* Clear sc_comp  */
        OutVoltAmpl_CR1_REG &= (uint8)(~OutVoltAmpl_COMP_MASK);
        /* Set sc_comp  */
        OutVoltAmpl_CR1_REG |= ( OutVoltAmpl_GainComp[gain] | OutVoltAmpl_COMP_MASK );
    }
}


/* [] END OF FILE */
