/*******************************************************************************
* File Name: SysClkCounter.h  
* Version 2.40
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
    
#if !defined(CY_COUNTER_SysClkCounter_H)
#define CY_COUNTER_SysClkCounter_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 SysClkCounter_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Counter_v2_40 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults        
**************************************/

#define SysClkCounter_Resolution            16u
#define SysClkCounter_UsingFixedFunction    1u
#define SysClkCounter_ControlRegRemoved     0u
#define SysClkCounter_COMPARE_MODE_SOFTWARE 0u
#define SysClkCounter_CAPTURE_MODE_SOFTWARE 0u
#define SysClkCounter_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Mode API Support
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct
{
    uint8 CounterEnableState; 
    uint16 CounterUdb;         /* Current Counter Value */

    #if (CY_UDB_V0)
        uint16 CounterPeriod;  /* Counter Period Value */
        uint16 CompareValue;   /* Counter Compare Value */           
        uint8 InterruptMaskValue;                   /* Counter Interrupt Mask Value */
    #endif /* (CY_UDB_V0) */

    #if (!SysClkCounter_ControlRegRemoved)
        uint8 CounterControlRegister;               /* Counter Control Register */
    #endif /* (!SysClkCounter_ControlRegRemoved) */

}SysClkCounter_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    SysClkCounter_Start(void) ;
void    SysClkCounter_Stop(void) ;
void    SysClkCounter_SetInterruptMode(uint8 interruptsMask) ;
uint8   SysClkCounter_ReadStatusRegister(void) ;
#define SysClkCounter_GetInterruptSource() SysClkCounter_ReadStatusRegister()
#if(!SysClkCounter_ControlRegRemoved)
    uint8   SysClkCounter_ReadControlRegister(void) ;
    void    SysClkCounter_WriteControlRegister(uint8 control) \
        ;
#endif /* (!SysClkCounter_ControlRegRemoved) */
#if (!(SysClkCounter_UsingFixedFunction && (CY_PSOC5A)))
    void    SysClkCounter_WriteCounter(uint16 counter) \
            ; 
#endif /* (!(SysClkCounter_UsingFixedFunction && (CY_PSOC5A))) */
uint16  SysClkCounter_ReadCounter(void) ;
uint16  SysClkCounter_ReadCapture(void) ;
void    SysClkCounter_WritePeriod(uint16 period) \
    ;
uint16  SysClkCounter_ReadPeriod( void ) ;
#if (!SysClkCounter_UsingFixedFunction)
    void    SysClkCounter_WriteCompare(uint16 compare) \
        ;
    uint16  SysClkCounter_ReadCompare( void ) \
        ;
#endif /* (!SysClkCounter_UsingFixedFunction) */

#if (SysClkCounter_COMPARE_MODE_SOFTWARE)
    void    SysClkCounter_SetCompareMode(uint8 compareMode) ;
#endif /* (SysClkCounter_COMPARE_MODE_SOFTWARE) */
#if (SysClkCounter_CAPTURE_MODE_SOFTWARE)
    void    SysClkCounter_SetCaptureMode(uint8 captureMode) ;
#endif /* (SysClkCounter_CAPTURE_MODE_SOFTWARE) */
void SysClkCounter_ClearFIFO(void)     ;
void SysClkCounter_Init(void)          ;
void SysClkCounter_Enable(void)        ;
void SysClkCounter_SaveConfig(void)    ;
void SysClkCounter_RestoreConfig(void) ;
void SysClkCounter_Sleep(void)         ;
void SysClkCounter_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define SysClkCounter__B_COUNTER__LESS_THAN 1
#define SysClkCounter__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define SysClkCounter__B_COUNTER__EQUAL 0
#define SysClkCounter__B_COUNTER__GREATER_THAN 3
#define SysClkCounter__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define SysClkCounter__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define SysClkCounter_CMP_MODE_LT 1u
#define SysClkCounter_CMP_MODE_LTE 2u
#define SysClkCounter_CMP_MODE_EQ 0u
#define SysClkCounter_CMP_MODE_GT 3u
#define SysClkCounter_CMP_MODE_GTE 4u
#define SysClkCounter_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define SysClkCounter__B_COUNTER__NONE 0
#define SysClkCounter__B_COUNTER__RISING_EDGE 1
#define SysClkCounter__B_COUNTER__FALLING_EDGE 2
#define SysClkCounter__B_COUNTER__EITHER_EDGE 3
#define SysClkCounter__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define SysClkCounter_CAP_MODE_NONE 0u
#define SysClkCounter_CAP_MODE_RISE 1u
#define SysClkCounter_CAP_MODE_FALL 2u
#define SysClkCounter_CAP_MODE_BOTH 3u
#define SysClkCounter_CAP_MODE_SOFTWARE_CONTROLLED 4u


/***************************************
 *  Initialization Values
 **************************************/
#define SysClkCounter_CAPTURE_MODE_CONF       0u
#define SysClkCounter_INIT_PERIOD_VALUE       65535u
#define SysClkCounter_INIT_COUNTER_VALUE      65535u
#if (SysClkCounter_UsingFixedFunction)
#define SysClkCounter_INIT_INTERRUPTS_MASK    ((uint8)((uint8)0u << SysClkCounter_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define SysClkCounter_INIT_COMPARE_VALUE      65535u
#define SysClkCounter_INIT_INTERRUPTS_MASK ((uint8)((uint8)0u << SysClkCounter_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        ((uint8)((uint8)0u << SysClkCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << SysClkCounter_STATUS_CMP_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << SysClkCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << SysClkCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT)))
#define SysClkCounter_DEFAULT_COMPARE_MODE    0u

#if( 0 != SysClkCounter_CAPTURE_MODE_CONF)
    #define SysClkCounter_DEFAULT_CAPTURE_MODE    ((uint8)((uint8)0u << SysClkCounter_CTRL_CAPMODE0_SHIFT))
#else    
    #define SysClkCounter_DEFAULT_CAPTURE_MODE    (0u )
#endif /* ( 0 != SysClkCounter_CAPTURE_MODE_CONF) */

#endif /* (SysClkCounter_UsingFixedFunction) */


/**************************************
 *  Registers
 *************************************/
#if (SysClkCounter_UsingFixedFunction)
    #define SysClkCounter_STATICCOUNT_LSB     (*(reg16 *) SysClkCounter_CounterHW__CAP0 )
    #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg16 *) SysClkCounter_CounterHW__CAP0 )
    #define SysClkCounter_PERIOD_LSB          (*(reg16 *) SysClkCounter_CounterHW__PER0 )
    #define SysClkCounter_PERIOD_LSB_PTR      ( (reg16 *) SysClkCounter_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define SysClkCounter_COMPARE_LSB         (*(reg16 *) SysClkCounter_CounterHW__CNT_CMP0 )
    #define SysClkCounter_COMPARE_LSB_PTR     ( (reg16 *) SysClkCounter_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define SysClkCounter_COUNTER_LSB         (*(reg16 *) SysClkCounter_CounterHW__CNT_CMP0 )
    #define SysClkCounter_COUNTER_LSB_PTR     ( (reg16 *) SysClkCounter_CounterHW__CNT_CMP0 )
    #define SysClkCounter_RT1                 (*(reg8 *) SysClkCounter_CounterHW__RT1)
    #define SysClkCounter_RT1_PTR             ( (reg8 *) SysClkCounter_CounterHW__RT1)
#else
    
    #if (SysClkCounter_Resolution <= 8u) /* 8-bit Counter */
    
        #define SysClkCounter_STATICCOUNT_LSB     (*(reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define SysClkCounter_PERIOD_LSB          (*(reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define SysClkCounter_PERIOD_LSB_PTR      ( (reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define SysClkCounter_COMPARE_LSB         (*(reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define SysClkCounter_COMPARE_LSB_PTR     ( (reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define SysClkCounter_COUNTER_LSB         (*(reg8 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
        #define SysClkCounter_COUNTER_LSB_PTR     ( (reg8 *)\
            SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
    
    #elif(SysClkCounter_Resolution <= 16u) /* 16-bit Counter */
        #if(CY_PSOC3) /* 8-bit address space */ 
            #define SysClkCounter_STATICCOUNT_LSB     (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define SysClkCounter_PERIOD_LSB          (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define SysClkCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define SysClkCounter_COMPARE_LSB         (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define SysClkCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define SysClkCounter_COUNTER_LSB         (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
            #define SysClkCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define SysClkCounter_STATICCOUNT_LSB     (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_F0_REG )
            #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_F0_REG )
            #define SysClkCounter_PERIOD_LSB          (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_D0_REG )
            #define SysClkCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_D0_REG )
            #define SysClkCounter_COMPARE_LSB         (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_D1_REG )
            #define SysClkCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_D1_REG )
            #define SysClkCounter_COUNTER_LSB         (*(reg16 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_A0_REG )  
            #define SysClkCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                SysClkCounter_CounterUDB_sC16_counterdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */   
    #elif(SysClkCounter_Resolution <= 24u) /* 24-bit Counter */
        
        #define SysClkCounter_STATICCOUNT_LSB     (*(reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define SysClkCounter_PERIOD_LSB          (*(reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define SysClkCounter_PERIOD_LSB_PTR      ( (reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define SysClkCounter_COMPARE_LSB         (*(reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define SysClkCounter_COMPARE_LSB_PTR     ( (reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define SysClkCounter_COUNTER_LSB         (*(reg32 *) \
            SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
        #define SysClkCounter_COUNTER_LSB_PTR     ( (reg32 *)\
            SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
    
    #else /* 32-bit Counter */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define SysClkCounter_STATICCOUNT_LSB     (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define SysClkCounter_PERIOD_LSB          (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define SysClkCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define SysClkCounter_COMPARE_LSB         (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define SysClkCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define SysClkCounter_COUNTER_LSB         (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
            #define SysClkCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define SysClkCounter_STATICCOUNT_LSB     (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_F0_REG )
            #define SysClkCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_F0_REG )
            #define SysClkCounter_PERIOD_LSB          (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_D0_REG )
            #define SysClkCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_D0_REG )
            #define SysClkCounter_COMPARE_LSB         (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_D1_REG )
            #define SysClkCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_D1_REG )
            #define SysClkCounter_COUNTER_LSB         (*(reg32 *) \
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_A0_REG )  
            #define SysClkCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                SysClkCounter_CounterUDB_sC16_counterdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */   
    #endif

	#define SysClkCounter_COUNTER_LSB_PTR_8BIT     ( (reg8 *)\
                SysClkCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
				
    #define SysClkCounter_AUX_CONTROLDP0 \
        (*(reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u0__DP_AUX_CTL_REG)
    
    #define SysClkCounter_AUX_CONTROLDP0_PTR \
        ( (reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u0__DP_AUX_CTL_REG)
    
    #if (SysClkCounter_Resolution == 16 || SysClkCounter_Resolution == 24 || SysClkCounter_Resolution == 32)
       #define SysClkCounter_AUX_CONTROLDP1 \
           (*(reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u1__DP_AUX_CTL_REG)
       #define SysClkCounter_AUX_CONTROLDP1_PTR \
           ( (reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u1__DP_AUX_CTL_REG)
    #endif /* (SysClkCounter_Resolution == 16 || SysClkCounter_Resolution == 24 || SysClkCounter_Resolution == 32) */
    
    #if (SysClkCounter_Resolution == 24 || SysClkCounter_Resolution == 32)
       #define SysClkCounter_AUX_CONTROLDP2 \
           (*(reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u2__DP_AUX_CTL_REG)
       #define SysClkCounter_AUX_CONTROLDP2_PTR \
           ( (reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u2__DP_AUX_CTL_REG)
    #endif /* (SysClkCounter_Resolution == 24 || SysClkCounter_Resolution == 32) */
    
    #if (SysClkCounter_Resolution == 32)
       #define SysClkCounter_AUX_CONTROLDP3 \
           (*(reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u3__DP_AUX_CTL_REG)
       #define SysClkCounter_AUX_CONTROLDP3_PTR \
           ( (reg8 *) SysClkCounter_CounterUDB_sC16_counterdp_u3__DP_AUX_CTL_REG)
    #endif /* (SysClkCounter_Resolution == 32) */

#endif  /* (SysClkCounter_UsingFixedFunction) */

#if (SysClkCounter_UsingFixedFunction)
    #define SysClkCounter_STATUS         (*(reg8 *) SysClkCounter_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define SysClkCounter_STATUS_MASK             (*(reg8 *) SysClkCounter_CounterHW__SR0 )
    #define SysClkCounter_STATUS_MASK_PTR         ( (reg8 *) SysClkCounter_CounterHW__SR0 )
    #define SysClkCounter_CONTROL                 (*(reg8 *) SysClkCounter_CounterHW__CFG0)
    #define SysClkCounter_CONTROL_PTR             ( (reg8 *) SysClkCounter_CounterHW__CFG0)
    #define SysClkCounter_CONTROL2                (*(reg8 *) SysClkCounter_CounterHW__CFG1)
    #define SysClkCounter_CONTROL2_PTR            ( (reg8 *) SysClkCounter_CounterHW__CFG1)
    #if (CY_PSOC3 || CY_PSOC5LP)
        #define SysClkCounter_CONTROL3       (*(reg8 *) SysClkCounter_CounterHW__CFG2)
        #define SysClkCounter_CONTROL3_PTR   ( (reg8 *) SysClkCounter_CounterHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define SysClkCounter_GLOBAL_ENABLE           (*(reg8 *) SysClkCounter_CounterHW__PM_ACT_CFG)
    #define SysClkCounter_GLOBAL_ENABLE_PTR       ( (reg8 *) SysClkCounter_CounterHW__PM_ACT_CFG)
    #define SysClkCounter_GLOBAL_STBY_ENABLE      (*(reg8 *) SysClkCounter_CounterHW__PM_STBY_CFG)
    #define SysClkCounter_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) SysClkCounter_CounterHW__PM_STBY_CFG)
    

    /********************************
    *    Constants
    ********************************/

    /* Fixed Function Block Chosen */
    #define SysClkCounter_BLOCK_EN_MASK          SysClkCounter_CounterHW__PM_ACT_MSK
    #define SysClkCounter_BLOCK_STBY_EN_MASK     SysClkCounter_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define SysClkCounter_CTRL_ENABLE_SHIFT      0x00u
    #define SysClkCounter_ONESHOT_SHIFT          0x02u
    /* Control Register Bit Masks */
    #define SysClkCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << SysClkCounter_CTRL_ENABLE_SHIFT))         
    #define SysClkCounter_ONESHOT                ((uint8)((uint8)0x01u << SysClkCounter_ONESHOT_SHIFT))

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        #define SysClkCounter_CTRL_MODE_SHIFT        0x01u    
        #define SysClkCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x07u << SysClkCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Use CFG2 Mode bits to set run mode */
        #define SysClkCounter_CTRL_MODE_SHIFT        0x00u    
        #define SysClkCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x03u << SysClkCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    /* Set the mask for interrupt (raw/status register) */
    #define SysClkCounter_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define SysClkCounter_CTRL2_IRQ_SEL          ((uint8)((uint8)0x01u << SysClkCounter_CTRL2_IRQ_SEL_SHIFT))     
    
    /* Status Register Bit Locations */
    #define SysClkCounter_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define SysClkCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      (SysClkCounter_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define SysClkCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << SysClkCounter_STATUS_ZERO_SHIFT))

    /* Status Register Interrupt Bit Masks*/
    #define SysClkCounter_STATUS_ZERO_INT_EN_MASK       ((uint8)((uint8)SysClkCounter_STATUS_ZERO >> 0x04u))
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define SysClkCounter_RT1_SHIFT            0x04u
    #define SysClkCounter_RT1_MASK             ((uint8)((uint8)0x03u << SysClkCounter_RT1_SHIFT))  /* Sync TC and CMP bit masks */
    #define SysClkCounter_SYNC                 ((uint8)((uint8)0x03u << SysClkCounter_RT1_SHIFT))
    #define SysClkCounter_SYNCDSI_SHIFT        0x00u
    #define SysClkCounter_SYNCDSI_MASK         ((uint8)((uint8)0x0Fu << SysClkCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    #define SysClkCounter_SYNCDSI_EN           ((uint8)((uint8)0x0Fu << SysClkCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    
#else /* !SysClkCounter_UsingFixedFunction */
    #define SysClkCounter_STATUS               (* (reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define SysClkCounter_STATUS_PTR           (  (reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define SysClkCounter_STATUS_MASK          (* (reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__MASK_REG )
    #define SysClkCounter_STATUS_MASK_PTR      (  (reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__MASK_REG )
    #define SysClkCounter_STATUS_AUX_CTRL      (*(reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define SysClkCounter_STATUS_AUX_CTRL_PTR  ( (reg8 *) SysClkCounter_CounterUDB_sSTSReg_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define SysClkCounter_CONTROL              (* (reg8 *) SysClkCounter_CounterUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG )
    #define SysClkCounter_CONTROL_PTR          (  (reg8 *) SysClkCounter_CounterUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG )


    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define SysClkCounter_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define SysClkCounter_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define SysClkCounter_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define SysClkCounter_CTRL_CMPMODE_MASK      0x07u 
    #define SysClkCounter_CTRL_CAPMODE_MASK      0x03u  
    #define SysClkCounter_CTRL_RESET             ((uint8)((uint8)0x01u << SysClkCounter_CTRL_RESET_SHIFT))  
    #define SysClkCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << SysClkCounter_CTRL_ENABLE_SHIFT)) 

    /* Status Register Bit Locations */
    #define SysClkCounter_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define SysClkCounter_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define SysClkCounter_STATUS_CMP_INT_EN_MASK_SHIFT       SysClkCounter_STATUS_CMP_SHIFT       
    #define SysClkCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      SysClkCounter_STATUS_ZERO_SHIFT      
    #define SysClkCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  SysClkCounter_STATUS_OVERFLOW_SHIFT  
    #define SysClkCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT SysClkCounter_STATUS_UNDERFLOW_SHIFT 
    #define SysClkCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT   SysClkCounter_STATUS_CAPTURE_SHIFT   
    #define SysClkCounter_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  SysClkCounter_STATUS_FIFOFULL_SHIFT  
    #define SysClkCounter_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  SysClkCounter_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define SysClkCounter_STATUS_CMP             ((uint8)((uint8)0x01u << SysClkCounter_STATUS_CMP_SHIFT))  
    #define SysClkCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << SysClkCounter_STATUS_ZERO_SHIFT)) 
    #define SysClkCounter_STATUS_OVERFLOW        ((uint8)((uint8)0x01u << SysClkCounter_STATUS_OVERFLOW_SHIFT)) 
    #define SysClkCounter_STATUS_UNDERFLOW       ((uint8)((uint8)0x01u << SysClkCounter_STATUS_UNDERFLOW_SHIFT)) 
    #define SysClkCounter_STATUS_CAPTURE         ((uint8)((uint8)0x01u << SysClkCounter_STATUS_CAPTURE_SHIFT)) 
    #define SysClkCounter_STATUS_FIFOFULL        ((uint8)((uint8)0x01u << SysClkCounter_STATUS_FIFOFULL_SHIFT))
    #define SysClkCounter_STATUS_FIFONEMP        ((uint8)((uint8)0x01u << SysClkCounter_STATUS_FIFONEMP_SHIFT))
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define SysClkCounter_STATUS_CMP_INT_EN_MASK            SysClkCounter_STATUS_CMP                    
    #define SysClkCounter_STATUS_ZERO_INT_EN_MASK           SysClkCounter_STATUS_ZERO            
    #define SysClkCounter_STATUS_OVERFLOW_INT_EN_MASK       SysClkCounter_STATUS_OVERFLOW        
    #define SysClkCounter_STATUS_UNDERFLOW_INT_EN_MASK      SysClkCounter_STATUS_UNDERFLOW       
    #define SysClkCounter_STATUS_CAPTURE_INT_EN_MASK        SysClkCounter_STATUS_CAPTURE         
    #define SysClkCounter_STATUS_FIFOFULL_INT_EN_MASK       SysClkCounter_STATUS_FIFOFULL        
    #define SysClkCounter_STATUS_FIFONEMP_INT_EN_MASK       SysClkCounter_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define SysClkCounter_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define SysClkCounter_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define SysClkCounter_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define SysClkCounter_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define SysClkCounter_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define SysClkCounter_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* SysClkCounter_UsingFixedFunction */

#endif  /* CY_COUNTER_SysClkCounter_H */


/* [] END OF FILE */

