/*******************************************************************************
* File Name: VDAC_CurrCompens_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_CurrCompens.h"

static VDAC_CurrCompens_backupStruct VDAC_CurrCompens_backup;


/*******************************************************************************
* Function Name: VDAC_CurrCompens_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_CurrCompens_SaveConfig(void) 
{
    if (!((VDAC_CurrCompens_CR1 & VDAC_CurrCompens_SRC_MASK) == VDAC_CurrCompens_SRC_UDB))
    {
        VDAC_CurrCompens_backup.data_value = VDAC_CurrCompens_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_CurrCompens_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_CurrCompens_RestoreConfig(void) 
{
    if (!((VDAC_CurrCompens_CR1 & VDAC_CurrCompens_SRC_MASK) == VDAC_CurrCompens_SRC_UDB))
    {
        if((VDAC_CurrCompens_Strobe & VDAC_CurrCompens_STRB_MASK) == VDAC_CurrCompens_STRB_EN)
        {
            VDAC_CurrCompens_Strobe &= (uint8)(~VDAC_CurrCompens_STRB_MASK);
            VDAC_CurrCompens_Data = VDAC_CurrCompens_backup.data_value;
            VDAC_CurrCompens_Strobe |= VDAC_CurrCompens_STRB_EN;
        }
        else
        {
            VDAC_CurrCompens_Data = VDAC_CurrCompens_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_CurrCompens_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_CurrCompens_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_CurrCompens_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_CurrCompens_ACT_PWR_EN == (VDAC_CurrCompens_PWRMGR & VDAC_CurrCompens_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_CurrCompens_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_CurrCompens_backup.enableState = 0u;
    }
    
    VDAC_CurrCompens_Stop();
    VDAC_CurrCompens_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_CurrCompens_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_CurrCompens_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_CurrCompens_Wakeup(void) 
{
    VDAC_CurrCompens_RestoreConfig();
    
    if(VDAC_CurrCompens_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_CurrCompens_Enable();

        /* Restore the data register */
        VDAC_CurrCompens_SetValue(VDAC_CurrCompens_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
