/*******************************************************************************
* File Name: VDAC_CurrProt_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_CurrProt.h"

static VDAC_CurrProt_backupStruct VDAC_CurrProt_backup;


/*******************************************************************************
* Function Name: VDAC_CurrProt_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_CurrProt_SaveConfig(void) 
{
    if (!((VDAC_CurrProt_CR1 & VDAC_CurrProt_SRC_MASK) == VDAC_CurrProt_SRC_UDB))
    {
        VDAC_CurrProt_backup.data_value = VDAC_CurrProt_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_CurrProt_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_CurrProt_RestoreConfig(void) 
{
    if (!((VDAC_CurrProt_CR1 & VDAC_CurrProt_SRC_MASK) == VDAC_CurrProt_SRC_UDB))
    {
        if((VDAC_CurrProt_Strobe & VDAC_CurrProt_STRB_MASK) == VDAC_CurrProt_STRB_EN)
        {
            VDAC_CurrProt_Strobe &= (uint8)(~VDAC_CurrProt_STRB_MASK);
            VDAC_CurrProt_Data = VDAC_CurrProt_backup.data_value;
            VDAC_CurrProt_Strobe |= VDAC_CurrProt_STRB_EN;
        }
        else
        {
            VDAC_CurrProt_Data = VDAC_CurrProt_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_CurrProt_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_CurrProt_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_CurrProt_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_CurrProt_ACT_PWR_EN == (VDAC_CurrProt_PWRMGR & VDAC_CurrProt_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_CurrProt_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_CurrProt_backup.enableState = 0u;
    }
    
    VDAC_CurrProt_Stop();
    VDAC_CurrProt_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_CurrProt_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_CurrProt_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_CurrProt_Wakeup(void) 
{
    VDAC_CurrProt_RestoreConfig();
    
    if(VDAC_CurrProt_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_CurrProt_Enable();

        /* Restore the data register */
        VDAC_CurrProt_SetValue(VDAC_CurrProt_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
