/*******************************************************************************
* File Name: VDAC_OverVolt_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_OverVolt.h"

static VDAC_OverVolt_backupStruct VDAC_OverVolt_backup;


/*******************************************************************************
* Function Name: VDAC_OverVolt_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OverVolt_SaveConfig(void) 
{
    if (!((VDAC_OverVolt_CR1 & VDAC_OverVolt_SRC_MASK) == VDAC_OverVolt_SRC_UDB))
    {
        VDAC_OverVolt_backup.data_value = VDAC_OverVolt_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_OverVolt_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OverVolt_RestoreConfig(void) 
{
    if (!((VDAC_OverVolt_CR1 & VDAC_OverVolt_SRC_MASK) == VDAC_OverVolt_SRC_UDB))
    {
        if((VDAC_OverVolt_Strobe & VDAC_OverVolt_STRB_MASK) == VDAC_OverVolt_STRB_EN)
        {
            VDAC_OverVolt_Strobe &= (uint8)(~VDAC_OverVolt_STRB_MASK);
            VDAC_OverVolt_Data = VDAC_OverVolt_backup.data_value;
            VDAC_OverVolt_Strobe |= VDAC_OverVolt_STRB_EN;
        }
        else
        {
            VDAC_OverVolt_Data = VDAC_OverVolt_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_OverVolt_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OverVolt_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_OverVolt_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_OverVolt_ACT_PWR_EN == (VDAC_OverVolt_PWRMGR & VDAC_OverVolt_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_OverVolt_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_OverVolt_backup.enableState = 0u;
    }
    
    VDAC_OverVolt_Stop();
    VDAC_OverVolt_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_OverVolt_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OverVolt_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_OverVolt_Wakeup(void) 
{
    VDAC_OverVolt_RestoreConfig();
    
    if(VDAC_OverVolt_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_OverVolt_Enable();

        /* Restore the data register */
        VDAC_OverVolt_SetValue(VDAC_OverVolt_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
