/*******************************************************************************
* File Name: VoutCtrl.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "VoutCtrl.h"


/*******************************************************************************
* Function Name: VoutCtrl_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void VoutCtrl_Write(uint8 value) 
{
    uint8 staticBits = (VoutCtrl_DR & (uint8)(~VoutCtrl_MASK));
    VoutCtrl_DR = staticBits | ((uint8)(value << VoutCtrl_SHIFT) & VoutCtrl_MASK);
}


/*******************************************************************************
* Function Name: VoutCtrl_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  VoutCtrl_DM_STRONG     Strong Drive 
*  VoutCtrl_DM_OD_HI      Open Drain, Drives High 
*  VoutCtrl_DM_OD_LO      Open Drain, Drives Low 
*  VoutCtrl_DM_RES_UP     Resistive Pull Up 
*  VoutCtrl_DM_RES_DWN    Resistive Pull Down 
*  VoutCtrl_DM_RES_UPDWN  Resistive Pull Up/Down 
*  VoutCtrl_DM_DIG_HIZ    High Impedance Digital 
*  VoutCtrl_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void VoutCtrl_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(VoutCtrl_0, mode);
}


/*******************************************************************************
* Function Name: VoutCtrl_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro VoutCtrl_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 VoutCtrl_Read(void) 
{
    return (VoutCtrl_PS & VoutCtrl_MASK) >> VoutCtrl_SHIFT;
}


/*******************************************************************************
* Function Name: VoutCtrl_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 VoutCtrl_ReadDataReg(void) 
{
    return (VoutCtrl_DR & VoutCtrl_MASK) >> VoutCtrl_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(VoutCtrl_INTSTAT) 

    /*******************************************************************************
    * Function Name: VoutCtrl_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 VoutCtrl_ClearInterrupt(void) 
    {
        return (VoutCtrl_INTSTAT & VoutCtrl_MASK) >> VoutCtrl_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
